import {select, json, tree, hierarchy, linkHorizontal, zoom, event} from 'd3';



const height = document.body.clientHeight;
const width = document.body.clientWidth;
const margin = {top: 20, right: 170, bottom: 30, left: 30};

const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;
const svg = d3.select("svg");


const treeLayout = tree()
			.size([innerHeight, innerWidth])



const g = svg.attr('width', width)
						 .attr('height', height)
					.append('g')
						.attr('transform', `translate(${margin.left}, ${margin.top})`);

svg.call(zoom().on('zoom' , () => {
	g.attr('transform', event.transform)
}));
json('data.json').then(data => {
	const root = hierarchy(data);
  const links = treeLayout(root).links();
  
  const linkPathGenerator = linkHorizontal()
  	 		.x(d => d.y)
  		 	.y(d => d.x);
  
  g.selectAll('path').data(links)
  		.enter().append('path')
  			.attr('d', linkPathGenerator);
  g.selectAll('text').data(root.descendants())
  	.enter().append('text')
  		.attr('x', d => d.y)
  		.attr('y', d => d.x)
  	  .attr('text-anchor', d => {
  			d.children ? 'middle' : 'start';
  		})
  		.attr('font-size', d => 3 - (d.depth / 1.2) + 'em')
  		.text(d => d.data.data.id)
  			.attr('dy', '0.32em')
});




